@@ -252,7 +252,7 @@ Wolfgang Sourdeau <wolfgang@logreport.org>
 
 =head1 VERSION
 
-$Id: ConfigFile.pm,v 1.8 2004/07/21 15:52:39 flacoste Exp $
+$Id: ConfigFile.pm,v 1.9 2006/07/23 13:16:30 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -272,7 +272,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
