@@ -309,7 +309,7 @@ __END__
 
 =head1 VERSION
 
-$Id: SpecParser.pm,v 1.43 2004/08/28 03:39:36 flacoste Exp $
+$Id: SpecParser.pm,v 1.44 2006/07/23 13:16:30 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -329,7 +329,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
