@@ -74,7 +74,7 @@ sub open {
     }
 
     $self->_load_config_file();
-    $self->{'_dbh'} = DBI->connect( "dbi:SQLite2:dbname=" .
+    $self->{'_dbh'} = DBI->connect( "dbi:SQLite:dbname=" .
                                     $self->{'_store_path'} . "/dlf.db", "", "",
                                     { 'RaiseError' => 1,
                                       'AutoCommit' => 0, } );
@@ -162,6 +162,12 @@ sub close {
     # DESTROY calls close() another time
     if ( $self->{'_dbh'} ) {
         $self->{'_dbh'}->commit();
+
+        # Clear any cached results from prepare_cached() before disconnecting,
+        # to avoid infamous 'closing dbh with active statement handle' warning.
+        my $CachedKids_hashref = $self->{'_dbh'}->{CachedKids};
+        %$CachedKids_hashref = () if $CachedKids_hashref;
+
         $self->{'_dbh'}->disconnect();
         delete $self->{'_dbh'};
         $self->{'_config'}->save()
@@ -387,14 +393,14 @@ sub dlf_streams {
     my $self = $_[0];
 
     my @streams = ();
-    my $sth = $self->{'_dbh'}->table_info( "", "", "dlf_%", "TABLE" );
-    $sth->execute();
-    while ( my $table_info = $sth->fetchrow_hashref() ) {
-        next unless $table_info->{'TABLE_NAME'} =~ /^dlf_(.*)/;
-        next if $table_info->{'TABLE_NAME'} =~ /_links$/;
+    # patch from Jean-Benoit Marzio, see:
+    # http://lists.logreport.org/pipermail/questions/2010/000861.html
+    my @table_list = $self->{'_dbh'}->tables;
+    foreach my $table ( @table_list) {
+        next unless $table =~ /dlf_(.*)"/;
+        next if $table =~ /_links$/;
         push @streams, $1;
     }
-    $sth->finish();
 
     return @streams;
 }
@@ -822,7 +828,7 @@ Lire::DlfConverter(3pm)
 
 =head1 VERSION
 
-$Id: DlfStore.pm,v 1.39 2006/07/23 13:16:29 vanbaal Exp $
+$Id: DlfStore.pm,v 1.41 2011/11/15 16:48:40 wraay Exp $
 
 =head1 COPYRIGHT
 
