@@ -281,19 +281,21 @@ sub log_fh {
 
 =pod
 
-=head2 run( $store )
+=head2 run( $store, [$time] )
 
-Runs this ImportJob and import it into the $store DlfStore.
+Runs this ImportJob and import it into the $store DlfStore. The $time
+parameter will be used to determine the time window covered by period.
+It defaults to the current time.
 
 =cut
 
 sub run {
-    my ( $self, $store ) = @_;
+    my ( $self, $store, $time ) = @_;
 
     check_object_param( $store, 'store', 'Lire::DlfStore' );
 
     my $process = new Lire::DlfConverterProcess( $self, $store );
-    $process->run_import_job();
+    $process->run_import_job( $time );
 
     my $converter = Lire::PluginManager->get_plugin( 'dlf_converter',
                                                      $self->{'_converter'} );
@@ -335,7 +337,7 @@ Lire::DlfStore(3pm) Lire::DlfConverter(3pm)
 
 =head1 VERSION
 
-$Id: ImportJob.pm,v 1.11 2004/06/29 18:37:03 flacoste Exp $
+$Id: ImportJob.pm,v 1.14 2006/07/23 13:16:29 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -355,7 +357,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
