@@ -72,8 +72,8 @@ sub init {
     setlocale( LC_ALL, '' );
 
     $SIG{'__WARN__'} = sub { $self->warning( @_ ); };
-    foreach my $name ( qw|.lire .lire/converters .lire/plugins .lire/reports 
-                          .lire/filters .lire/schemas| )
+    foreach my $name ( qw|.lire .lire/converters .lire/plugins .lire/reports
+                          .lire/filters .lire/schemas .lire/templates| )
     {
         my $dir = "$ENV{'HOME'}/$name";
         unless ( -d $dir  ) {
@@ -106,6 +106,12 @@ sub DESTROY {
     return;
 }
 
+=pod
+
+=head2 set_usage( [$usage] )
+
+=cut
+
 sub set_usage {
     my ( $self, $usage ) = @_;
 
@@ -114,6 +120,12 @@ sub set_usage {
     return;
 }
 
+=pod
+
+=head2 set_help( [$help] )
+
+=cut
+
 sub set_help {
     my ( $self, $help ) = @_;
 
@@ -122,6 +134,12 @@ sub set_help {
     return;
 }
 
+=pod
+
+=head2 set_section( [$name], [$label] )
+
+=cut
+
 sub add_section {
     my ( $self, $name, $label ) = @_;
     check_param( $name, 'name' );
@@ -131,6 +149,12 @@ sub add_section {
     return;
 }
 
+=pod
+
+=head2 add_option( [%args] )
+
+=cut
+
 sub add_option {
     my ( $self, %args ) = @_;
 
@@ -152,6 +176,12 @@ sub add_option {
     return;
 }
 
+=pod
+
+=head2 add_common_options()
+
+=cut
+
 sub add_common_options {
     my $self = $_[0];
 
@@ -452,7 +482,7 @@ sub handle_logfile {
     my $out_fh;
     if ( $algo ) {
         $self->info( __x( 'Log file was compressed using {algo}.',
-                     'algo' => $algo ) );
+                          'algo' => $algo ) );
         $self->error( __( "gzip(1) isn't available" ) )
           unless Lire::Config->get_var( 'gzip_path' )->is_valid();
         my $gzip = Lire::Config->get( 'gzip_path' );
@@ -482,6 +512,19 @@ sub handle_logfile {
     return;
 }
 
+=pod
+
+=head2 import_log( [$converter], [$logfile] )
+
+import_log invokes Lire::ImportJob and Lire::DlfConverterProcess.
+It uses &handle_logfile.
+
+This means that in case the $logfile is compressed, it is decompressed to a
+file in $TMPDIR.  In case the $logfile is read from a pipe or from STDIN, it is
+written to a file in $TMPDIR.  So, if you're short on discspace, pass the
+logfile as an uncompressed file.
+
+=cut
 
 sub import_log {
     my ( $self, $converter, $logfile ) = @_;
@@ -549,6 +592,15 @@ sub find_superservice {
     return ($plugin->schemas())[0];
 }
 
+=pod
+
+=head2 generate_report( [$converter], [$logfile] )
+
+Generate a report from a $logfile, using $converter.  Returns $reportfile.
+Uses Lire::ReportConfig::generate_report to do the real work.
+
+=cut
+
 sub generate_report {
     my ( $self, $converter, $logfile ) = @_;
 
@@ -559,12 +611,12 @@ sub generate_report {
     $self->init_report_config( $converter );
     $self->import_log( $converter, $logfile );
 
-    $self->info( 'Running analysers...' );
+    $self->info( __( 'Running analysers...' ) );
     my $cfg = $self->{'_report_cfg'};
     eval { $cfg->create_analyser_streams( $self->{'_store'} ) };
     $self->error( $@ ) if $@;
 
-    $self->info( 'Generating XML report...' );
+    $self->info( __( 'Generating XML report...' ) );
     my $report = eval { $cfg->generate_report( $self->{'_store'} ) };
     $self->error( $@ ) if $@;
 
@@ -720,3 +772,48 @@ sub email_report {
 }
 
 1;
+
+
+__END__
+
+=pod
+
+=head1 SEE ALSO
+
+lr_log2report(1), lr_log2mail(1), lr_xml2mail(1), lr_xml2report(1),
+Lire::Config(3pm), Lire::ReportConfig(3pm), Lire::PluginManager(3pm),
+Lire::DlfStore(3pm), Lire::ImportJob(3pm), Lire::OutputJob(3pm),
+Lire::DlfConverterProcess(3pm)
+
+=head1 AUTHOR
+
+  Francis J. Lacoste <flacoste@logreport.org>
+
+=head1 VERSION
+
+$Id: LrCommand.pm,v 1.9 2006/07/23 13:16:29 vanbaal Exp $
+
+=head1 COPYRIGHT
+
+Copyright (C) 2004 Stichting LogReport Foundation LogReport@LogRepor
+t.org
+
+This file is part of Lire.
+
+Lire is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program (see COPYING); if not, check with
+http://www.gnu.org/copyleft/gpl.html.
+
+=cut
+
+
