@@ -349,7 +349,7 @@ Lire::ReportJob(3pm) Lire::OutputFormat(3pm)
 
 =head1 VERSION
 
-$Id: OutputJob.pm,v 1.7 2004/08/30 00:43:38 flacoste Exp $
+$Id: OutputJob.pm,v 1.8 2006/07/23 13:16:29 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -369,7 +369,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
