@@ -677,7 +677,7 @@ Lire::Report::Subreport(3pm) Lire::Report::ColumnInfo(3pm)
 
 =head1 VERSION
 
-$Id: GroupInfo.pm,v 1.21 2004/05/10 06:23:22 wsourdeau Exp $
+$Id: GroupInfo.pm,v 1.22 2006/07/23 13:16:31 vanbaal Exp $
 
 =head1 AUTHOR
 
@@ -701,7 +701,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software 
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html. 
 
 =cut
