@@ -524,7 +524,7 @@ Lire::Report::Group(3pm), Lire::Report::ChartConfig(3pm)
 
 =head1 VERSION
 
-$Id: Subreport.pm,v 1.45 2004/08/23 21:17:21 flacoste Exp $
+$Id: Subreport.pm,v 1.46 2006/07/23 13:16:31 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -544,8 +544,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software 
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html. 
 
 =head1 AUTHOR
 
