@@ -1106,7 +1106,7 @@ __END__
 
 =head1 VERSION
 
-$Id: ReportParser.pm,v 1.51 2004/07/21 16:11:27 flacoste Exp $
+$Id: ReportParser.pm,v 1.52 2006/07/23 13:16:29 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -1126,7 +1126,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
