@@ -89,12 +89,12 @@ sub write_report {
     $self->{ '_format'} = $format;
     $self->{'_outputfile'} = $outputfile;
     $self->{'_outputdir'} = dirname( $outputfile );
-    $self->{'_outputbase'} = $outputfile;
+    $self->{'_outputbase'} = basename( $outputfile );
     $self->{'_outputbase'} =~ s/\.\w+?$//;
     $self->{'_preamble'} = $preamble;
 
-    open $self->{'_fh'}, "> $self->{'_outputbase'}.tex"
-      or die "can't write to $self->{'_outputbase'}.tex\n";
+    open $self->{'_fh'}, "> $self->{'_outputdir'}/$self->{'_outputbase'}.tex"
+      or die "can't write to $self->{'_outputdir'}/$self->{'_outputbase'}.tex\n";
     set_fh_encoding( $self->{'_fh'}, 'utf-8' );
 
 
@@ -409,7 +409,7 @@ sub create_dvi {
     my $lambda = Lire::Config->get( 'lambda_path' );
     my $status = system( "cd $self->{'_outputdir'} && $lambda -interaction=batchmode $self->{'_outputbase'} >/dev/null 2>/dev/null" );
 
-    my $log = file_content( "$self->{'_outputbase'}.log" );
+    my $log = file_content( "$self->{'_outputdir'}/$self->{'_outputbase'}.log" );
     if ( !$status ) {
         # No error, check for rerun
         $self->create_dvi() if $log =~ /rerun/i;
@@ -457,7 +457,7 @@ Lire::OutputFormat(3pm) Lire::OutputFormats::LaTeX(3pm)
 
 =head1 VERSION
 
-$Id: LaTeXWriter.pm,v 1.16 2006/07/23 13:16:31 vanbaal Exp $
+$Id: LaTeXWriter.pm,v 1.17 2006/07/29 17:57:34 vanbaal Exp $
 
 =head1 COPYRIGHT
 
