@@ -375,7 +375,7 @@ lire(1), Curses::UI(3pm)
 
 =head1 VERSION
 
-$Id: UI.pm,v 1.24 2004/09/01 21:25:22 flacoste Exp $
+$Id: UI.pm,v 1.25 2006/07/23 13:16:30 vanbaal Exp $
 
 =head1 AUTHORS
 
@@ -400,7 +400,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
