@@ -255,7 +255,7 @@ lr_spec2pot(1)
 
 =head1 VERSION
 
-$Id: XMLSpecI18N.pm,v 1.10 2004/08/05 01:16:15 wsourdeau Exp $
+$Id: XMLSpecI18N.pm,v 1.11 2006/07/23 13:16:30 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -275,7 +275,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software 
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html. 
 
 =cut
