@@ -6,7 +6,7 @@ use tests::ConfigValuesTest;
 use Lire::Config::TypeSpec;
 use Lire::Config::Object;
 
-use base qw/tests::ConfigValuesValueTest/;
+use base qw/tests::ConfigValueTest/;
 
 sub new {
     my $self = shift->SUPER::new( @_ );
@@ -33,20 +33,19 @@ sub spec {
 sub test_as_value {
     my $self = $_[0];
 
-    my $e_object = bless( { 's1' => undef, 's2' => undef },
+    my $e_object = bless( { 's1' => '', 's2' => '' },
                         'tests::ConfigObjectTest::Mock' );
 
     local $SIG{'__WARN__'} = sub { $self->annotate( @_ ) };
     my $object = $self->{'object_spec'}->instance()->as_value() || '<undef>';
-    $self->assert( UNIVERSAL::isa( $object, 'tests::ConfigObjectTest::Mock' ),
-                   "expected a tests::ConfigObjectTest::Mock: $object" );
+    $self->assert_isa( 'tests::ConfigObjectTest::Mock', $object );
     $self->assert_deep_equals( $e_object, $object );
 }
 
 package tests::ConfigObjectTest::Mock;
 
 sub new_from_config {
-    return bless $_[1], $_[0];
+    return bless ( $_[1]->Lire::Config::Dictionary::as_value(), $_[0] );
 }
 
 $INC{'tests/ConfigObjectTest/Mock.pm'} = __FILE__;
