@@ -4,15 +4,12 @@ use strict;
 
 use base qw/Test::Unit::TestSuite/;
 
-use Lire::Config::TypeSpec;
-use Carp;
-
 sub name {
     return "Configuration Specification Tests";
 }
 
 sub include_tests {
-    return qw/tests::ConfigListSpecTest
+    return qw/tests::ConfigListSpecTest tests::ConfigTypeSpecTest
               tests::ConfigFileSpecTest tests::ConfigExecutableSpecTest
               tests::ConfigDirectorySpecTest tests::ConfigBooleanSpecTest
               tests::ConfigStringSpecTest tests::ConfigIntegerSpecTest
@@ -21,10 +18,12 @@ sub include_tests {
             /;
 }
 
-package tests::ConfigTypeSpecTest;
+package tests::ConfigTypeSpecBase;
 
 use base qw/Lire::Test::TestCase tests::TestStoreFixture /;
 
+use Lire::Config::TypeSpec;
+
 sub new {
     my $self = shift()->SUPER::new( @_ );
 
@@ -36,23 +35,26 @@ sub new {
 
 sub set_up {
     my $self = $_[0];
-
     $self->SUPER::set_up();
     $self->set_up_locale();
+    $self->set_up_spec();
 
-    $self->{'spec'} = $self->type->new( 'name' => "test_spec",
-                                        $self->additional_new_params(),
-                                      );
+    return;
 }
 
 sub tear_down {
     my $self = $_[0];
-
     $self->SUPER::tear_down();
     $self->tear_down_locale();
 
-    # Since we aren't calling our parent's set_up, we shouldn't
-    # call our parent's tear_down().
+    return;
+}
+
+sub set_up_spec {
+    my $self = $_[0];
+
+    $self->{'spec'} = $self->type()->new( 'name' => "test_spec",
+                                          $self->additional_new_params() );
 }
 
 sub additional_new_params { return () }
@@ -64,83 +66,178 @@ sub test_new {
     my $spec = $type->new( 'name' => "parameter",
                            'summary' => "Parameter Summary",
                            'description' => "<para>Parameter Description</para>",
+                           'required' => 0,
+                           'obsolete' => 1,
                            $self->additional_new_params(),
                          );
-    $self->assert_not_null( $spec, "$type->new returned undef" );
-    $self->assert( UNIVERSAL::isa( $spec, $type ),
-                   "$type->new returned value of wrong type: $spec"
-                 );
+    $self->assert_isa( $type, $spec );
+
     $self->assert_str_equals( "parameter", $spec->name() );
     $self->assert_str_equals( "Parameter Summary", $spec->summary() );
     $self->assert_str_equals( "<para>Parameter Description</para>",
                               $spec->description() );
+    $self->assert( ! $spec->required(), '!required()' );
+    $self->assert( $spec->obsolete(), 'obsolete()' );
 
-    $self->assert_died( sub { $type->new( $self->additional_new_params() ) },
-                        qr/missing 'name' parameter/ );
-    $self->assert_died( sub { $type->new( 'name' => 'wrong%name',
-                                          $self->additional_new_params() ) },
-                        qr/name should only contain/ );
+    $self->assert_dies( qr/missing 'name' parameter/,
+                        sub { $type->new( $self->additional_new_params() ) } );
+    $self->assert_dies( qr/name should only contain/,
+                        sub { $type->new( 'name' => 'wrong%name',
+                                          $self->additional_new_params() ) } );
+}
+
+package MockTypeSpec;
+
+use base qw/Lire::Config::TypeSpec/;
+
+sub instance_class {
+    return "MockValue";
+}
+
+package MockValue;
+
+use base qw/Lire::Config::Value/;
+
+package tests::ConfigTypeSpecTest;
+
+use base qw/tests::ConfigTypeSpecBase/;
+
+use Lire::Utils qw/deep_copy/;
+
+sub type {
+    return "MockTypeSpec";
 }
 
 sub test_instance {
     my $self = $_[0];
 
     my $value = $self->{'spec'}->instance();
-    $self->assert_not_null( $value, $self->type() .
-                            "->instance() returned undef" );
-    $self->assert( UNIVERSAL::isa( $value, $self->value_type() ),
-                   $self->type() . "->instance() returned value of wrong type: $value" );
+    $self->assert_isa( 'MockValue', $value );
+
+    $value->{'my_attribute'} = 3;
+    $self->{'spec'}{'_default'} = $value;
+
+    my $default = $self->{'spec'}->instance();
+    $self->assert_str_not_equals( $value, $default );
+    $self->assert_deep_equals( $value, $default );
+}
+
+sub test_default {
+    my $self = $_[0];
+
+    my $spec = $self->{'spec'};
+    $self->assert( ! $spec->has_default(), "!has_default()" );
+    $self->assert_null( $spec->default(), "default() -> !undef" );
+
+    my $value = $spec->instance();
+
+    $spec->default( $value );
+    $self->assert_str_equals( $value, $spec->{'_default'} );
+    $self->assert( $spec->has_default(), "has_default() != 1" );
+    $self->assert_str_equals( $value, $spec->default() );
+
+    my $spec2 = deep_copy( $spec );
+    $self->assert_dies( qr/default value doesn't come from this specification/,
+                        sub { $spec->default( $spec2->instance() ) } );
+
+
+    $spec->default( undef );
+    $self->assert_null( $spec->{'_default'} );
+}
+
+sub test_required {
+    my $self = $_[0];
+
+    my $spec = $self->{'spec'};
+    $self->assert_num_equals( 1, $spec->{'_required'} );
+    $self->assert_num_equals( 1, $spec->required() );
+    $spec->required( 0 );
+    $self->assert_num_equals( 0, $spec->{'_required'} );
+}
+
+sub test_obsolete {
+    my $self = $_[0];
+
+    my $spec = $self->{'spec'};
+    $self->assert_num_equals( 0, $spec->{'_obsolete'} );
+    $self->assert_num_equals( 0, $spec->obsolete() );
+    $spec->obsolete( 1 );
+    $self->assert_num_equals( 1, $spec->{'_obsolete'} );
 }
 
 sub test_is_instance {
     my $self = $_[0];
 
     my $value = $self->{'spec'}->instance();
-
     $self->assert( $self->{'spec'}->is_instance( $value ),
                    "is_instance() returned false",
                  );
-    $self->assert_died( sub { $self->{'spec'}->is_instance() },
-                        qr/missing \'instance\' parameter/ );
-    $self->assert_died( sub { $self->{'spec'}->is_instance( $self->{'spec'}) },
-                        qr/\'instance\' parameter should be a \'Lire::Config::Value\' instance, not/ );
+    $self->assert_dies( qr/missing \'instance\' parameter/,
+                        sub { $self->{'spec'}->is_instance() } );
+    $self->assert_dies( qr/\'instance\' parameter should be a \'Lire::Config::Value\' instance, not/,
+                        sub { $self->{'spec'}->is_instance( $self->{'spec'}) } );
 
-    my $bad_value = $self->type->new( 'name'=> "bad_name",
-                                      $self->additional_new_params(),
-                                    )->instance();
+    my $bad_value = $self->type()->new( 'name'=> "bad_name",
+                                        $self->additional_new_params(),
+                                      )->instance();
     $self->assert( ! $self->{'spec'}->is_instance( $bad_value ),
                    "is_instance() with value with different name should return false"
                  );
 
-    my $clone = $self->type->new( 'name' => $self->{'spec'}->name(),
-                                  $self->additional_new_params(),
-                                )->instance();
+    my $clone = $self->type()->new( 'name' => $self->{'spec'}->name(),
+                                    $self->additional_new_params(),
+                                  )->instance();
     $self->assert( ! $self->{'spec'}->is_instance( $clone ),
-                   "is_instance() with different spec should die" );
+                   "is_instance() with different spec should fail" );
 }
 
-
 sub test_summary {
     my $self = $_[0];
 
     $self->assert_str_equals( "test_spec", $self->{'spec'}->summary() );
     $self->{'spec'}->summary( 'Test Summary' );
     $self->assert_str_equals( "Test Summary", $self->{'spec'}{'summary'} );
-    $self->assert_str_equals("Test Summary", $self->{'spec'}->summary(), );
+    $self->assert_str_equals("Test Summary", $self->{'spec'}->summary() );
+
+    $self->{'spec'}->summary( "Summary with\nnewlines   \n   and wawas" );
+    $self->assert_str_equals( "Summary with\nnewlines   \n   and wawas",
+                              $self->{'spec'}{'summary'} );
+    $self->assert_str_equals( 'Summary with newlines and wawas',
+                              $self->{'spec'}->summary() );
+
+    no warnings 'redefine';
+    my $dgettext_param = '';
+    my $dgettext = sub {
+        $dgettext_param = $_[1];
+        return "  dgettext\ncalled\n";
+    };
+    local *Lire::Config::TypeSpec::dgettext = $dgettext;
+    $self->assert_str_equals( "  dgettext\ncalled\n",
+                              $self->{'spec'}->summary() );
+    $self->assert_str_equals ( 'Summary with newlines and wawas',
+                               $dgettext_param );
+
+    return;
 }
 
 sub test_description {
     my $self = $_[0];
 
-    $self->assert_null( $self->{'spec'}->description,
+    $self->assert_null( $self->{'spec'}->description(),
                         "uninitialized description should be empty" );
 
     my $desc = "<para>Description</para>";
     $self->{'spec'}->description( $desc );
-    $self->assert_equals( $desc, $self->{'spec'}->description );
+    $self->assert_equals( $desc, $self->{'spec'}->description() );
 
-    $self->assert_died( sub {$self->{'spec'}->description( "Description" ) },
-                        qr/'description' parameter should be a DocBook/ );
+
+    $self->assert_dies( qr/'description' parameter should be a DocBook/,
+                        sub {$self->{'spec'}->description( "Description" ) } );
+
+    $desc = "<para>Multi-line\n   description</para>";
+    $self->{'spec'}->description( $desc );
+    $self->assert_equals( "<para>Multi-line description</para>",
+                          $self->{'spec'}->description() );
 }
 
 sub test_summary_i18n {
@@ -149,10 +246,12 @@ sub test_summary_i18n {
     my $spec = $self->{'spec'};
     $spec->{'i18n_domain'} = 'lire-test';
     $spec->{'summary'} = 'JPEG Files';
+    $self->annotate( "There is a bug somewhere that seems to prevent the locale to be set correctly to 'C'." );
     $self->assert_str_equals( 'JPEG Files', $spec->summary() );
-    $self->set_locale( 'fr_CA' );
+    $self->set_locale( 'fr_CA.iso8859-1' );
     $self->assert_str_equals( 'Fichiers JPEG', $spec->summary() );
 
+    return;
 }
 
 sub test_description_i18n {
@@ -161,9 +260,10 @@ sub test_description_i18n {
     my $spec = $self->{'spec'};
     $spec->{'description'} = '<para>JPEG Files</para>';
     $spec->{'i18n_domain'} = 'lire-test';
+    $self->annotate( "There is a bug somewhere that seems to prevent the locale to be set correctly to 'C'." );
     $self->assert_str_equals( '<para>JPEG Files</para>',
                               $spec->description() );
-    $self->set_locale( 'fr_CA' );
+    $self->set_locale( 'fr_CA.iso8859-1' );
     $self->assert_str_equals( '<para>Fichiers JPEG</para>',
                               $spec->description() );
 }
@@ -190,7 +290,9 @@ EOT
 
 package tests::ConfigScalarSpecTest;
 
-use base qw/tests::ConfigTypeSpecTest/;
+use base qw/tests::ConfigTypeSpecBase/;
+
+use Lire::Config::ScalarSpec;
 
 sub test_normalize {
     my $self = $_[0];
@@ -221,29 +323,29 @@ sub test_is_valid {
     $self->assert( ! $warning, "is_valid( undef ) had warnings: $warning" );
     foreach my $v ( $self->valid_test_data ) {
         $self->assert( $self->{'spec'}->is_valid( $v ),
-                       $self->type . "->is_valid should return true for $v" );
+                       $self->type(). "->is_valid should return true for $v" );
         $self->assert( ! $warning, "is_valid( '$v' ) had warnings: $warning" );
     }
 
     foreach my $v ( $self->invalid_test_data ) {
         $self->assert( !$self->{'spec'}->is_valid( $v ),
-                       $self->type . "->is_valid should return false for $v" );
+                       $self->type(). "->is_valid should return false for $v" );
         $self->assert( ! $warning, "is_valid( '$v' ) had warnings: $warning" );
     }
+    $self->{'spec'}->required( 0 );
+    $self->assert_num_equals( 1, $self->{'spec'}->is_valid( undef ) );
 }
 
 package tests::ConfigFileSpecTest;
 
 use base qw/tests::ConfigScalarSpecTest/;
 
+use Lire::Config::FileSpec;
+
 sub type {
     return 'Lire::Config::FileSpec';
 }
 
-sub value_type {
-    return 'Lire::Config::Scalar';
-}
-
 sub normalize_test_data {
     return (
             "/etc/passwd" => "/etc/passwd",
@@ -263,6 +365,8 @@ package tests::ConfigExecutableSpecTest;
 
 use base qw/tests::ConfigScalarSpecTest/;
 
+use Lire::Config::ExecutableSpec;
+
 sub set_up {
     my $self = $_[0];
     $self->SUPER::set_up();
@@ -283,10 +387,6 @@ sub type {
     return 'Lire::Config::ExecutableSpec';
 }
 
-sub value_type {
-    return 'Lire::Config::Scalar';
-}
-
 sub normalize_test_data {
     return (
             "sh" => "/bin/sh",
@@ -309,16 +409,13 @@ package tests::ConfigDirectorySpecTest;
 
 use base qw/tests::ConfigScalarSpecTest/;
 
+use Lire::Config::DirectorySpec;
 use File::Basename;
 
 sub type {
     return 'Lire::Config::DirectorySpec';
 }
 
-sub value_type {
-    return 'Lire::Config::Scalar';
-}
-
 sub normalize_test_data {
     return (
             "/etc/passwd" => "/etc/passwd",
@@ -339,26 +436,17 @@ package tests::ConfigListSpecTest;
 
 use base qw/tests::ConfigCompoundSpecTest/;
 
+use Lire::Config::ListSpec;
+
 sub type {
     return 'Lire::Config::ListSpec';
 }
 
-sub value_type {
-    return 'Lire::Config::List';
-}
-
-sub test_instance {
-    shift->tests::ConfigTypeSpecTest::test_instance();
-}
-
-sub test_is_instance {
-    shift->tests::ConfigTypeSpecTest::test_is_instance();
-}
-
 package tests::ConfigConfigSpecTest;
 
-use base qw/tests::ConfigTypeSpecTest/;
+use base qw/tests::ConfigTypeSpecBase/;
 
+use Lire::Config::ConfigSpec;
 
 sub test_components_by_section {
     my $self = $_[0];
@@ -374,8 +462,8 @@ sub test_components_by_section {
     $spec->add( $test2_spec );
     $spec->add( $test3_spec );
 
-    $self->assert_died( sub { $spec->components_by_section() },
-                        qr/missing 'section' parameter/ );
+    $self->assert_dies( qr/missing 'section' parameter/,
+                        sub { $spec->components_by_section() } );
     $self->assert_deep_equals( [ $test1_spec, $test3_spec ],
                                $spec->components_by_section( 'section1' ) );
     $self->assert_deep_equals( [ $test2_spec ],
@@ -388,30 +476,37 @@ sub type {
     return 'Lire::Config::ConfigSpec';
 }
 
-sub value_type {
-    return 'Lire::Config::Dictionary';
-}
-
 sub test_new {
     my $self = $_[0];
 
-    my $spec = $self->type->new();
-    $self->assert_not_null( $spec, "new() returned undef" );
-    $self->assert( UNIVERSAL::isa( $spec, $self->type ),
-                   "new() returned value of wrong type: $spec"
-                 );
+    my $spec = $self->type()->new();
+    $self->assert_isa( $self->type(), $spec );
 }
 
 package tests::ConfigStringSpecTest;
 
 use base qw/tests::ConfigScalarSpecTest/;
 
-sub type {
-    return 'Lire::Config::StringSpec';
+use Lire::Config::StringSpec;
+
+sub test_valid_re {
+    my $self = $_[0];
+
+    my $string = new Lire::Config::StringSpec( 'name' => 'valid-re',
+                                               'valid-re' => '^\w+$' );
+    $self->assert_str_equals( qr/^\w+$/, $string->{'_compiled_re'} );
+    $self->assert_str_equals( '^\w+$', $string->valid_re() );
+    $string->valid_re( undef );
+    $self->assert_null( $string->{'_compiled_re'} );
+    $self->assert_null( $string->{'_valid_re'} );
+
+    $string->valid_re( '^\d+$' );
+    $self->assert( $string->is_valid( 10 ), 'is_valid( 10 )' );
+    $self->assert( ! $string->is_valid( 'abc' ), '!is_valid( "abc" )' );
 }
 
-sub value_type {
-    return 'Lire::Config::Scalar';
+sub type {
+    return 'Lire::Config::StringSpec';
 }
 
 sub normalize_test_data {
@@ -432,14 +527,12 @@ package tests::ConfigIntegerSpecTest;
 
 use base qw/tests::ConfigScalarSpecTest/;
 
+use Lire::Config::IntegerSpec;
+
 sub type {
     return 'Lire::Config::IntegerSpec';
 }
 
-sub value_type {
-    return 'Lire::Config::Scalar';
-}
-
 sub normalize_test_data {
     return (
             0 => 0,
@@ -460,14 +553,12 @@ package tests::ConfigBooleanSpecTest;
 
 use base qw/tests::ConfigScalarSpecTest/;
 
+use Lire::Config::BooleanSpec;
+
 sub type {
     return 'Lire::Config::BooleanSpec';
 }
 
-sub value_type {
-    return 'Lire::Config::Scalar';
-}
-
 sub normalize_test_data {
     return (
             '' => '',
@@ -500,6 +591,8 @@ package tests::ConfigSelectSpecTest;
 
 use base qw/tests::ConfigScalarSpecTest/;
 
+use Lire::Config::SelectSpec;
+
 sub set_up {
     my $self = $_[0];
 
@@ -514,10 +607,6 @@ sub type {
     return "Lire::Config::SelectSpec";
 }
 
-sub value_type {
-    return "Lire::Config::Scalar";
-}
-
 sub normalize_test_data {
     return (
             'option_1' => "option_1",
@@ -552,18 +641,21 @@ sub test_add {
     $self->assert_deep_equals( [ sort ($option_1, $option_2) ],
                                [ sort $select->options ] );
 
-    $self->assert_died( sub { $select->add( undef ) },
-                        qr/missing 'option' parameter/ );
-#     $self->assert_died( sub { $select->add( new Lire::Config::OptionSpec( 'name' => "OPTION_1" ) ) },
-#                         qr/already contains an option named 'option_1'/ );
+    $self->assert_dies( qr/missing 'option' parameter/,
+                        sub { $select->add( undef ) } );
+#    $self->assert_dies( qr/already contains an option named 'option_1'/,
+#                         sub { $select->add( new Lire::Config::OptionSpec( 'name' => "OPTION_1" ) ) },
+# );
 
-    $self->assert_died( sub { $select->add( new Lire::Config::ListSpec( 'name' => "OPTION_1" ) ) },
-                              qr/\'option\' parameter should be a \'Lire::Config::OptionSpec\' instance, not \'Lire::Config::ListSpec/ );
+    $self->assert_dies( qr/\'option\' parameter should be a \'Lire::Config::OptionSpec\' instance, not \'Lire::Config::ListSpec/,
+                      sub { $select->add( new Lire::Config::ListSpec( 'name' => "OPTION_1" ) ) } );
 }
 
 package tests::ConfigOptionSpecTest;
 
-use base qw/tests::ConfigTypeSpecTest/;
+use base qw/tests::ConfigTypeSpecBase/;
+
+use Lire::Config::OptionSpec;
 
 sub type {
     return "Lire::Config::OptionSpec";
@@ -572,8 +664,8 @@ sub type {
 sub test_instance  {
     my $self = $_[0];
 
-    $self->assert_died( sub { $self->{'spec'}->instance() },
-                        qr/not implemented/ );
+    $self->assert_dies( qr/not implemented/,
+                        sub { $self->{'spec'}->instance() });
 }
 
 sub test_is_instance {
@@ -588,6 +680,8 @@ package tests::ConfigCommandSpecTest;
 
 use base qw/tests::ConfigScalarSpecTest/;
 
+use Lire::Config::CommandSpec;
+
 use File::Basename;
 
 sub set_up {
@@ -610,10 +704,6 @@ sub type {
     return 'Lire::Config::CommandSpec';
 }
 
-sub value_type {
-    return 'Lire::Config::Scalar';
-}
-
 sub normalize_test_data {
     return (
             "//bin//sh" => "/bin/sh",
