@@ -2,7 +2,7 @@ package tests::DlfConverterProcessTest;
 
 use strict;
 
-use base qw/ Lire::Test::DlfConverterTestCase /;
+use base qw/ tests::DlfConverterProcessFixture /;
 
 use Lire::DlfConverterProcess;
 use Lire::Utils qw/tempfile/;
@@ -53,16 +53,22 @@ EOF
      'test1' =>
      [
       {
+       'dlf_id'  => 1,
+       'dlf_source' => 'myjob-20040311',
        'time'    => 90000,
        'code'    => 500,
        'message' => "This is a long message",
       },
       {
+       'dlf_id'  => 2,
+       'dlf_source' => 'myjob-20040311',
        'time'    => undef,
        'code'    => undef,
        'message' => undef,
       },
       {
+       'dlf_id'  => 3,
+       'dlf_source' => 'myjob-20040311',
        'time'    => 100000,
        'code'    => undef,
        'message' => "Another message",
@@ -71,6 +77,8 @@ EOF
      'test2' =>
      [
       {
+       'dlf_id'  => 1,
+       'dlf_source' => 'myjob-20040311',
        'time_start' => 1023456,
        'file' => "/var/tmp",
        'result' => "OK",
@@ -114,6 +122,8 @@ my $cont_results =
     {
      'test1' => [
                {
+                'dlf_id'  => 1,
+                'dlf_source' => 'myjob-20040311',
                 'time'    => 90000,
                 'code'    => 500,
                 'message' => "This is a long message",
@@ -121,6 +131,8 @@ my $cont_results =
               ],
      'test2' => [
                {
+                'dlf_id'  => 1,
+                'dlf_source' => 'myjob-20040311',
                 'time_start' => 1023456,
                 'file' => "/var/tmp",
                 'result' => "OK",
@@ -155,8 +167,9 @@ sub test_new {
     my $p = new Lire::DlfConverterProcess( $self->import_job( "test_line"),
                                            $self->dlf_store() );
     $self->assert_isa( 'Lire::DlfConverterProcess', $p );
-    $self->assert_equals( $self->import_job( "test_line" ), $p->import_job() );
-    $self->assert_equals( $self->dlf_store(), $p->dlf_store() );
+    $self->assert_str_equals( $self->import_job( "test_line" ),
+                              $p->import_job() );
+    $self->assert_str_equals( $self->dlf_store(), $p->dlf_store() );
 }
 
 sub test_run_import_job_line {
@@ -165,8 +178,8 @@ sub test_run_import_job_line {
     $self->import_job( "test_line" )->converter( "line" );
     my $p = new Lire::DlfConverterProcess( $self->import_job( "test_line" ),
                                            $self->dlf_store() );
-    $self->assert_not_null( $p, "new() returned undef" );
-
+    $self->assert_isa( 'Lire::DlfConverterProcess', $p );
+    $p->{'_job_id'} = 'myjob-20040311';
     $p->run_import_job();
 
     $self->assert_dlf_converter_match_results( $logs{'test_line'}, $p );
@@ -180,9 +193,10 @@ sub test_run_import_job_file {
 
     $self->import_job( "test_file" )->converter( "file" );
     my $p = new Lire::DlfConverterProcess( $self->import_job( "test_file" ),
-                                           $self->dlf_store );
-    $self->assert_not_null( $p, "new() returned undef" );
+                                           $self->dlf_store() );
+    $self->assert_isa( 'Lire::DlfConverterProcess', $p );
 
+    $p->{'_job_id'} = 'myjob-20040311';
     $p->run_import_job();
     $self->assert_dlf_converter_match_results( $logs{'test_file'}, $p );
 }
@@ -192,15 +206,17 @@ sub test_convert_continuation {
 
     $self->import_job( "continuation" )->converter( "line" );
     my $p = new Lire::DlfConverterProcess( $self->import_job( "continuation" ),
-                                           $self->dlf_store );
-    $self->assert_not_null( $p, "new() returned undef" );
+                                           $self->dlf_store() );
+    $self->assert_isa( 'Lire::DlfConverterProcess', $p );
 
+    $p->{'_job_id'} = 'myjob-20040311';
     $p->run_import_job();
     $self->assert_dlf_converter_match_results( $logs{'continuation'}, $p );
 
     # Should process saved lines now
     $p = new Lire::DlfConverterProcess( $self->import_job( "continuation" ),
                                         $self->dlf_store() );
+    $p->{'_job_id'} = 'myjob-20040311';
     $p->run_import_job();
     $self->assert_dlf_converter_match_results( $cont_results, $p );
 }
