@@ -14,6 +14,14 @@ sub set_up {
     return;
 }
 
+sub tear_down {
+    my $self = $_[0];
+
+    $self->SUPER::tear_down();
+
+    return;
+}
+
 sub test_lr_missing_cases {
     my $self = $_[0];
 
