@@ -32,7 +32,15 @@ sub set_up {
                                     'field' => 'file_size',
                                     'name' => 'max' );
 
-    return  $self;
+    return;
+}
+
+sub tear_down {
+    my $self = $_[0];
+
+    $self->SUPER::tear_down();
+
+    return;
 }
 
 sub test_sql_aggr_expr {
