@@ -47,7 +47,7 @@ sub test_label_i18n {
 
     my $op = $self->{'op'};
     $self->assert_str_equals( 'JPEG Files', $op->label() );
-    $self->set_locale( 'fr_CA' );
+    $self->set_locale( 'fr_CA.iso8859-1' );
     $self->assert_str_equals( 'Fichiers JPEG', $op->label() );
 }
 
