@@ -2,16 +2,11 @@ package tests::UICommandWidgetTest;
 
 use strict;
 
-no warnings 'redefine';
-
 use base qw/ Lire::Test::TestCase /;
 
 use Lire::Config::TypeSpec;
-
-use Curses::UI;
-use File::Basename qw/ dirname basename /;
-
 use Lire::Test::CursesUIDriver;
+use Curses::UI;
 
 sub set_up {
     my $self = $_[0];
@@ -46,10 +41,8 @@ sub test_new {
 
     my $widget = $self->{'window'}->add( 'cmd_widget', 'Lire::UI::CommandWidget',
                                          'value' => $self->{'cmd_param'} );
-    $self->assert( UNIVERSAL::isa( $widget, 'Lire::UI::ExecutableWidget' ),
-                   "not a Lire::UI::ExecutableWidget instance: $widget" );
-    $self->assert( UNIVERSAL::isa( $widget, 'Lire::UI::CommandWidget' ),
-                   "not a Lire::UI::ExecutableWidget instance: $widget" );
+    $self->assert_isa( 'Lire::UI::ExecutableWidget', $widget );
+    $self->assert_isa( 'Lire::UI::CommandWidget', $widget,  );
 }
 
 1;
