@@ -167,6 +167,26 @@ sub test_child_focus_cb {
 
     $self->assert_str_equals( 'string', $help_summary->text() );
     $self->assert_str_equals( 'No help available.', $help_viewer->text() );
+
+    my $texteditor = '<undef>';
+    my $nothing = '<undef>';
+    my $scrollpos = 0;
+
+    no warnings 'redefine';
+    local *Curses::UI::TextViewer::cursor_up =
+      sub { $texteditor = shift; $nothing = shift; $scrollpos = shift; };
+
+    $help_viewer->{'-yscrpos'} = 1;
+    Lire::UI::CompoundWidget::_child_focus_cb( $widget->getobj('list_widget') );
+
+    $self->assert_str_equals( '<undef>', $texteditor );
+
+    $help_viewer->{'-yscrpos'} = 3;
+    Lire::UI::CompoundWidget::_child_focus_cb( $widget->getobj('list_widget') );
+
+    $self->assert_str_equals( $help_viewer, $texteditor );
+    $self->assert_null( $nothing );
+    $self->assert_num_equals( 3, $scrollpos );
 }
 
 sub test_layout {
