@@ -256,7 +256,7 @@ sub test_option_change_cb {
     my $opt_summary = $driver->find_widget( '/prefs_win/option_summary' );
     $self->assert_str_equals( 'Test Summary', $opt_summary->text() );
     my $opt_help = $driver->find_widget( '/prefs_win/option_help' );
-    $self->assert_str_equals( 'Test Description', $opt_help->text() );
+   $self->assert_str_equals( 'Test Description', $opt_help->text() );
 
     my $opt_widget =
       $driver->find_widget( '/prefs_win' )->getobj( 'option_widget' );
@@ -272,7 +272,30 @@ sub test_option_change_cb {
 
     $options->{'-selected'} = 2;
     Lire::UI::Prefs::_option_change_cb( $options );
-    $self->assert_str_equals( 'Summary with newlines and wawas', $opt_summary->text() );
+    $self->assert_str_equals( 'Summary with newlines and wawas',
+                              $opt_summary->text() );
+
+    my $texteditor = '<undef>';
+    my $nothing = '<undef>';
+    my $scrollpos = 0;
+
+    no warnings 'redefine';
+    local *Curses::UI::TextEditor::cursor_up =
+      sub { $texteditor = shift; $nothing = shift; $scrollpos = shift; };
+
+    $opt_help->{'-yscrpos'} = 1;
+    $options->{'-selected'} = 1;
+    Lire::UI::Prefs::_option_change_cb( $options );
+
+    $self->assert_str_equals( '<undef>', $texteditor );
+
+    $opt_help->{'-yscrpos'} = 3;
+    $options->{'-selected'} = 2;
+    Lire::UI::Prefs::_option_change_cb( $options );
+
+    $self->assert_str_equals( $opt_help, $texteditor );
+    $self->assert_null( $nothing );
+    $self->assert_num_equals( 3, $scrollpos );
 
     return;
 }
