@@ -40,7 +40,7 @@ sub test_xml_encode {
 sub test_latex_encode {
     my $self = $_[0];
 
-    $self->assert_str_equals( '\\# \\$ \\& \\~ \\_ \\^ \\% \\{ \\} $\\backslash$ Other $[$ $]$ $<$ $>$',  latex_encode( '# $ & ~ _ ^ % { } \\ Other [ ] < >' ) );
+    $self->assert_str_equals( '\\# \\$ \\& \\~{} \\_ \\^{} \\% \\{ \\} $\\backslash$ Other $[$ $]$ $<$ $>$',  latex_encode( '# $ & ~ _ ^ % { } \\ Other [ ] < >' ) );
 }
 
 sub test_diff_lists {
