@@ -24,23 +24,17 @@ sub test_lr_environment {
     $self->assert_matches( qr/lr_debug=''/,  $result->stdout() );
     $self->assert_matches( qr/lr_spool_interval='300'/, $result->stdout() );
 
-    # Test backward compatibility vars
-    $self->assert_matches( qr/LR_SPOOLINTERVAL='300'/, $result->stdout() );
-    $self->assert_matches( qr/export.*LR_SPOOLINTERVAL/, $result->stdout() );
 }
 
 sub test_shell_env {
     my $self = $_[0];
 
     my $lr_env = ac_path( 'libexecdir', 'PACKAGE') . "/lr_environment";
-    my $result = $self->lire_run( qq{ eval `$lr_env`; echo "lr_debug=\$lr_debug"x; echo "LR_SPOOLINTERVAL=\$LR_SPOOLINTERVAL"x; echo "lr_test_uid=\$lr_test_uid"x; echo "lr_spool_interval=\$lr_spool_interval"x } );
+    my $result = $self->lire_run( qq{ eval `$lr_env`; echo "lr_debug=\$lr_debug"x; echo "lr_test_uid=\$lr_test_uid"x; echo "lr_spool_interval=\$lr_spool_interval"x } );
     $self->annotate( $result->stderr() );
     $self->assert_equals( 0, $result->status() );
     $self->assert_matches( qr/lr_test_uid=1x/, $result->stdout() );
     $self->assert_matches( qr/lr_debug=x/,  $result->stdout() );
 
-    # Test backward compatibility vars
-    $self->assert_matches( qr/LR_SPOOLINTERVAL=300x/,
-                           $result->stdout() );
 }
 1;
