@@ -31,7 +31,8 @@ sub init_dlf_converter {}
 sub process_log_file {
     my ( $self, $process, $fd ) = @_;
 
-    my @fields = qw/time_start time_end time_taken connection_id client_host
+    my @fields = qw/dlf_id dlf_source time_start time_end time_taken
+                     connection_id client_host
                     user file file_size complete /;
     my $line;
     while ( defined( $line = <$fd> ) ) {
