@@ -40,7 +40,7 @@ sub test_categorise {
 
     $dlf->{'useragent'} = 'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; fr)';
     $analyser->categorise( $dlf );
-    $self->assert_str_equals( 'MS Internet Exporer', $dlf->{'browser'} );
+    $self->assert_str_equals( 'MS Internet Explorer', $dlf->{'browser'} );
     $self->assert_str_equals( 'Windows', $dlf->{'os'} );
     $self->assert_str_equals( 'French', $dlf->{'lang'} );
 
